@@ -34,7 +34,8 @@ from shogun.Kernel import LinearKernel, PolyKernel, LocalAlignmentStringKernel
 from shogun.Kernel import LocalityImprovedStringKernel
 from shogun.Kernel import CommWordStringKernel, WeightedCommWordStringKernel
 from shogun.Kernel import CombinedKernel
-from shogun.Kernel import FULL_NORMALIZATION, SLOWBUTMEMEFFICIENT
+from shogun.Kernel import SLOWBUTMEMEFFICIENT
+from shogun.Kernel import AvgDiagKernelNormalizer
 from shogun.Features import RealFeatures, Labels, StringCharFeatures, DNA, StringWordFeatures
 from shogun.Features import CombinedFeatures
 from shogun.Classifier import LibSVM,GPBTSVM
@@ -67,12 +68,10 @@ def create_features(kname, examples, kparam, train_mode, preproc):
         feats = RealFeatures(examples)
         
     elif kname == 'wd' or kname == 'localalign' or kname == 'localimprove':
-        feats = StringCharFeatures(DNA)
-        feats.set_string_features(examples)
+        feats = StringCharFeatures(examples, DNA)
 
     elif kname == 'spec' or kname == 'cumspec':
-        feats = StringCharFeatures(DNA)
-        feats.set_string_features(examples)
+        feats = StringCharFeatures(examples, DNA)
 
         wf = StringWordFeatures( feats.get_alphabet() )
         wf.obtain_from_char(feats, kparam['degree']-1, kparam['degree'], 0, kname=='cumspec')
@@ -95,8 +94,7 @@ def create_features(kname, examples, kparam, train_mode, preproc):
 
         (ex0,ex1) = zip(*examples)
 
-        f0 = StringCharFeatures(DNA)
-        f0.set_string_features(list(ex0))
+        f0 = StringCharFeatures(list(ex0), DNA)
         wf = StringWordFeatures(f0.get_alphabet())
         wf.obtain_from_char(f0, kparam['degree']-1, kparam['degree'], 0, reversed)
         del f0
@@ -110,8 +108,7 @@ def create_features(kname, examples, kparam, train_mode, preproc):
         feats['combined'].append_feature_obj(wf)
         feats['f0'] = wf
 
-        f1 = StringCharFeatures(DNA)
-        f1.set_string_features(list(ex1))
+        f1 = StringCharFeatures(list(ex1), DNA)
         wf = StringWordFeatures( f1.get_alphabet() )
         wf.obtain_from_char(f1, kparam['degree']-1, kparam['degree'], 0, reversed)
         del f1
@@ -136,11 +133,13 @@ def create_kernel(kname,kparam,feats_train):
     if kname == 'gauss':
         kernel = GaussianKernel(feats_train, feats_train, kparam['width'])
     elif kname == 'linear':
-        kernel = LinearKernel(feats_train, feats_train, kparam['scale'])
+        kernel = LinearKernel(feats_train, feats_train)
+        kernel.set_normalizer(AvgDiagKernelNormalizer(kparam['scale']))
     elif kname == 'poly':
         kernel = PolyKernel(feats_train, feats_train, kparam['degree'], kparam['inhomogene'], kparam['normal'])
     elif kname == 'wd':
         kernel=WeightedDegreePositionStringKernel(feats_train, feats_train, kparam['degree'])
+        kernel.set_normalizer(AvgDiagKernelNormalizer(float(kparam['seqlength'])))
         kernel.set_shifts(kparam['shift']*numpy.ones(kparam['seqlength'],dtype=numpy.int32))
         #kernel=WeightedDegreeStringKernel(feats_train, feats_train, kparam['degree'])
     elif kname == 'spec':
@@ -177,6 +176,25 @@ def create_kernel(kname,kparam,feats_train):
     kernel.set_cache_size(32) 
     return kernel
 
+def create_combined_kernel(kname, kparam, examples, train_mode, preproc):
+    """A wrapper for creating combined kernels.
+
+    kname, kparam and examples are lists.
+
+    """
+    num_kernels = len(kname)
+    feats['combined'] = CombinedFeatures()
+    kernel = CombinedKernel()
+
+    for kix in xrange(num_kernels):
+        cur_kname = '%s%d' % (kname[kix],kix)
+        (cur_feats, cur_preproc) = create_features(kname[kix], examples[kix], kparam[kix], train_mode, preproc)
+        feats[cur_kname] = cur_feats
+        cur_kernel = create_kernel(kname[kix], kparam[kix], cur_feats)
+        kernel.append_kernel(cur_kernel)
+
+    return (feats,kernel)
+
 def model2str(kparam,C,kp,shownames=True):
     """Generates a string describing the model parameters"""
 
