@@ -8,7 +8,7 @@
  * Copyright (C) 2009 Fraunhofer Institute FIRST and Max-Planck-Society
  */
 #include <iostream>
-#include <shogun/lib/io.h>
+#include <shogun/io/SGIO.h>
 #include <shogun/lib/ShogunException.h>
 #include <shogun/kernel/CustomKernel.h>
 #include <shogun/kernel/CombinedKernel.h>
@@ -114,9 +114,9 @@ void gentrainkernel(float64_t * & ker1 ,float64_t * & ker2, float64_t * & ker3
 
 	float64_t fm1=0, mean1=0,fm2=0, mean2=0,fm3=0, mean3=0;
 
-	ker1=new float64_t[ x.size()*x.size()];
-	ker2=new float64_t[ x.size()*x.size()];
-	ker3=new float64_t[ x.size()*x.size()];
+	ker1=SG_MALLOC(float64_t,  x.size()*x.size());
+	ker2=SG_MALLOC(float64_t,  x.size()*x.size());
+	ker3=SG_MALLOC(float64_t,  x.size()*x.size());
 
 
 	for(size_t l=0; l< x.size();++l)
@@ -164,9 +164,9 @@ void gentestkernel(float64_t * & ker1 ,float64_t * & ker2,float64_t * & ker3,
 		const std::vector<float64_t> & x,const std::vector<float64_t> & y,
 		const std::vector<float64_t> & tx,const std::vector<float64_t> & ty)
 {
-	ker1=new float64_t[ x.size()*tx.size()];
-	ker2=new float64_t[ x.size()*tx.size()];
-	ker3=new float64_t[ x.size()*tx.size()];
+	ker1=SG_MALLOC(float64_t,  x.size()*tx.size());
+	ker2=SG_MALLOC(float64_t,  x.size()*tx.size());
+	ker3=SG_MALLOC(float64_t,  x.size()*tx.size());
 
 	for(size_t l=0; l< x.size();++l)
 	{
@@ -218,9 +218,9 @@ void tester()
 	CCustomKernel* kernel2=new CCustomKernel();
 	CCustomKernel* kernel3=new CCustomKernel();
 
-	kernel1->set_full_kernel_matrix_from_full(ker1, numdata,numdata);
-	kernel2->set_full_kernel_matrix_from_full(ker2, numdata,numdata);
-	kernel3->set_full_kernel_matrix_from_full(ker3, numdata,numdata);
+	kernel1->set_full_kernel_matrix_from_full(SGMatrix<float64_t>(ker1, numdata,numdata));
+	kernel2->set_full_kernel_matrix_from_full(SGMatrix<float64_t>(ker2, numdata,numdata));
+	kernel3->set_full_kernel_matrix_from_full(SGMatrix<float64_t>(ker3, numdata,numdata));
 
 	ker->append_kernel(kernel1);
 	ker->append_kernel(kernel2);
@@ -242,7 +242,7 @@ void tester()
 	SG_SPRINT("finished svm training\n");
 
 	//starting svm testing on training data
-	CLabels* res=tsvm->classify();
+	CLabels* res=tsvm->apply();
 	ASSERT(res);
 
 	float64_t err=0;
@@ -256,9 +256,9 @@ void tester()
 	SG_SPRINT("prediction error on training data (3 classes): %f ",err);
 	SG_SPRINT("random guess error would be: %f \n",2/3.0);
 
-	delete[] ker1;
-	delete[] ker2;
-	delete[] ker3;
+	SG_FREE(ker1);
+	SG_FREE(ker2);
+	SG_FREE(ker3);
 
 	//generate test data
 	CLabels* tlab=NULL;
@@ -281,9 +281,9 @@ void tester()
 	CCustomKernel* tkernel2=new CCustomKernel();
 	CCustomKernel* tkernel3=new CCustomKernel();
 
-	tkernel1->set_full_kernel_matrix_from_full(tker1,numdata, numdatatest);
-	tkernel2->set_full_kernel_matrix_from_full(tker2,numdata, numdatatest);
-	tkernel3->set_full_kernel_matrix_from_full(tker2,numdata, numdatatest);
+	tkernel1->set_full_kernel_matrix_from_full(SGMatrix<float64_t>(tker1,numdata, numdatatest));
+	tkernel2->set_full_kernel_matrix_from_full(SGMatrix<float64_t>(tker2,numdata, numdatatest));
+	tkernel3->set_full_kernel_matrix_from_full(SGMatrix<float64_t>(tker2,numdata, numdatatest));
 
 	tker->append_kernel(tkernel1);
 	tker->append_kernel(tkernel2);
@@ -303,8 +303,8 @@ void tester()
 	tker->set_subkernel_weights(weights, numweights);
 	tsvm->set_kernel(tker);
 
-	//compute classif error, check mem
-	CLabels* tres=tsvm->classify();
+	//compute classification error, check mem
+	CLabels* tres=tsvm->apply();
 
 	float64_t terr=0;
 	for(int32_t i=0; i<numdatatest;++i)
@@ -317,9 +317,9 @@ void tester()
 	SG_SPRINT("prediction error on test data (3 classes): %f ",terr);
 	SG_SPRINT("random guess error would be: %f \n",2/3.0);
 
-	delete[] tker1;
-	delete[] tker2;
-	delete[] tker3;
+	SG_FREE(tker1);
+	SG_FREE(tker2);
+	SG_FREE(tker3);
 	SG_UNREF(tsvm);
 	SG_UNREF(res);
 	SG_UNREF(tres);
@@ -327,7 +327,7 @@ void tester()
 	SG_UNREF(tlab);
 	SG_UNREF(tker);
 
-	delete[] weights;
+	SG_FREE(weights);
 	weights=NULL;
 
 	SG_SPRINT( "finished \n");
@@ -336,7 +336,7 @@ void tester()
 namespace shogun
 {
 	extern Version* sg_version;
-	extern IO* sg_io;
+	extern SGIO* sg_io;
 }
 
 int main()
@@ -355,4 +355,6 @@ int main()
 	}
 
 	exit_shogun();
+
+	return 0;
 }
