@@ -1,6 +1,12 @@
-def sparse_euclidian_distance ():
-	print 'SparseEuclidianDistance'
+from tools.load import LoadMatrix
+lm=LoadMatrix()
 
+traindat = lm.load_numbers('../data/fm_train_real.dat')
+testdat = lm.load_numbers('../data/fm_test_real.dat')
+
+parameter_list = [[traindat,testdat],[traindat,testdat]]
+
+def distance_sparseeuclidean_modular (fm_train_real=traindat,fm_test_real=testdat):
 	from shogun.Features import RealFeatures, SparseRealFeatures
 	from shogun.Distance import SparseEuclidianDistance
 
@@ -17,10 +23,8 @@ def sparse_euclidian_distance ():
 	distance.init(feats_train, feats_test)
 	dm_test=distance.get_distance_matrix()
 
+	return distance,dm_train,dm_test
 
 if __name__=='__main__':
-	from tools.load import LoadMatrix
-	lm=LoadMatrix()
-	fm_train_real=lm.load_numbers('../data/fm_train_real.dat')
-	fm_test_real=lm.load_numbers('../data/fm_test_real.dat')
-	sparse_euclidian_distance()
+	print 'SparseEuclidianDistance'
+	distance_sparseeuclidean_modular(*parameter_list[0])
