@@ -24,5 +24,5 @@ svm <- SVMSGD(C, feats_train, labels)
 dump <- svm$train(svm)
 
 dump <- svm$set_features(svm, feats_test)
-lab <- svm$classify(svm)
+lab <- svm$apply(svm)
 out <- lab$get_labels(lab)
